Skip to contents

Load default content for createCohorts.R

Usage

createCohortsFun(path = ".")

Arguments

path

Character string identifying the path to the study project, default ".".

Value

A character vector containing the default contents of createCohorts.R.