Skip to contents

Checks out the develop branch and pulls changes from its remote.

Usage

devCheckout()

Value

Git log messages after checking out and pulling 'develop'

Examples

if (FALSE) { # \dontrun{
# Requires access to the configured Git remote
devCheckout(
)
} # }