`developCheckout()` is a wrapper for gert functions to swiftly default to develop and pull latest changes
developCheckout.Rd`developCheckout()` is a wrapper for gert functions to swiftly default to develop and pull latest changes
developCheckout.Rd`developCheckout()` is a wrapper for gert functions to swiftly default to develop and pull latest changes