Skip to contents

Creates the standard structure required for a new OMOP study package. It includes standard folders, R scripts, test and documentation files and it installs a default list of DARWIN EU®/OHDSI packages.

Usage

insertStructure(path = ".", n_obj = 3)

Arguments

path

Character string identifying the path to the study project, default ".".

n_obj

Number of study objectives, default n_obj = 3.

Value

No return value.

Details

It assumes an active R project has already been created and renv initialized.

Examples

if (FALSE) { # \dontrun{

# Creating package structure in current project

# - Initialize renv
renv::init()

# - Install package development tools
renv::install(c("usethis",
                "devtools",
                "studyGenerics"))

# - Initialize DESCRIPTION
usethis::use_description()

# - Initialize package structure
studyGenerics::insertStructure()

# - Initialize NAMESPACE
devtools::document()

# - Check package is valid
devtools::check()
} # }