Skip to contents

Creates the tests folder and populates the tests/testthat folder with a default test file for each script found in the R folder.

Usage

insertTests(path = ".")

Arguments

path

Character string identifying the path to the study project, default ".".

Value

No return value.