Skip to contents

Load default content for runDiagnostics.R

Usage

runDiagnosticsFun(path = ".")

Arguments

path

Character string identifying the path to the study project, default ".".

Value

A character vector containing the default contents of runDiagnostics.R.