R/insertStructure.R
createCohortsFun.Rd
Load default content for createCohorts.R
createCohortsFun(path = ".")
Character string identifying the path to the study project, default ".".
"."
A character vector containing the default contents of createCohorts.R.
createCohorts.R