Creates the inst and extras folders and populates the R folder with
ready files for standard study functions.
Usage
insertStudyFiles(path = ".", n_obj = 3)
Arguments
- path
Character string identifying the path to the study project,
default ".".
- n_obj
Number of study objectives, default n_obj = 3.