Creates the tests folder and populates the tests/testthat folder with
a default test file for each script found in the R folder.
Creates the tests folder and populates the tests/testthat folder with
a default test file for each script found in the R folder.