Insert default test files
insertTests.RdCreates the `tests` folder and populates the `tests/testthat` folder with a default test file for each script found in the `R` folder.
insertTests.RdCreates the `tests` folder and populates the `tests/testthat` folder with a default test file for each script found in the `R` folder.