R/insertStructure.R
runDiagnosticsFun.Rd
Load default content for runDiagnostics.R
runDiagnosticsFun(path = ".")
Character string identifying the path to the study project, default ".".
"."
A character vector containing the default contents of runDiagnostics.R.
runDiagnostics.R